#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import polyaxon_sdk


class V1ScheduleKind(polyaxon_sdk.V1ScheduleKind):
    CHOICES = (
        (polyaxon_sdk.V1ScheduleKind.CRON, polyaxon_sdk.V1ScheduleKind.CRON),
        (polyaxon_sdk.V1ScheduleKind.DATETIME, polyaxon_sdk.V1ScheduleKind.DATETIME),
        (polyaxon_sdk.V1ScheduleKind.INTERVAL, polyaxon_sdk.V1ScheduleKind.INTERVAL),
    )
