#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from mock import patch

from click.testing import CliRunner

from tests.utils import BaseTestCase


class BaseCommandTestCase(BaseTestCase):
    def setUp(self):
        super().setUp()
        self.runner = CliRunner()
        self.mock_config()

    def mock_config(self):
        patcher = patch("polyaxon.managers.client.ClientConfigManager.get_value")
        patcher.start()
        self.addCleanup(patcher.stop)
